@@ -932,12 +932,20 @@ class SourcePoint(GeospatialCoordinate):
 
     @property
     def __geo_interface__(self):
-        return {'type': 'Point',
-                'coordinates': (self.x.meters, self.y.meters, self.z.meters),
-                'properties': {'heading': self.heading_degrees,
-                               'pitch': self.pitch_degrees,
-                               'roll': self.roll_degrees,
-                               'time': self.time}}
+        if isinstance(self.time, float):
+            return {'type': 'Point',
+                    'coordinates': (self.x.meters, self.y.meters, self.z.meters),
+                    'properties': {'heading': self.heading_degrees,
+                                   'pitch': self.pitch_degrees,
+                                   'roll': self.roll_degrees,
+                                   'time': self.time}}
+        else:
+            return {'type': 'Point',
+                    'coordinates': (self.x.meters, self.y.meters, self.z.meters),
+                    'properties': {'heading': self.heading_degrees,
+                                   'pitch': self.pitch_degrees,
+                                   'roll': self.roll_degrees,
+                                   'time': self.time.strftime('%Y-%m-%d %H:%M:%S.%f')}}
 
 
 class AtmosphericPoint(GeospatialCoordinate):
